#!/bin/sh

# restartserver.sh by [BiM]gtk. For restarting a server periodically if its
# empty. Servers sometimes build up a memory footprint and doesnt free the ram
# it allocates, after a while it starts to run sluggish or other misc weird
# stuff can happen to long-running server processes. This script is meant 
# to be run from cron either @weekly or @daily. It depends on qstat.  Compile 
# & install qstat if your Linux distribution does not provide a qstat package!
# URL: http://www.qstat.org

# the full path to qstat
QSTAT="/usr/local/bin/qstat"
# called quakestat on Debian Linux
#QSTAT="/usr/bin/quakestat"

# README! 

# To automatically restart the server daily if its empty: 
# -------------------------------------------------------

# Add the script to crontab by doing: "crontab -e" then add the following:
# (without the quotes and the # at the start).

# "@daily /path/to/q3/seals/restartserver.sh /path/to/q3/seals/startserver.sh"

# To the above for each server you have configured and point to its 
# startserver.sh for its configuration.

# To automatically start the server whenever the box is rebooted:
# ---------------------------------------------------------------

#  add:
# "@reboot /path/to/q3/seals/startserver.sh start" 

# To silence mails:
# -----------------

# Both lines will give you a mail to the account the script run as with the
# output of the script each time it runs which can be annoying. to silence it 
# add a "&>/dev/null" at the end of the line without the quotes

# Thats it. [BiM]gtk

# No configuration should be necessary below this line!

if [ -z "$1" ]; then
   echo "usage $0: <full path to servers startserver.sh>"
else
    if [ -x "$QSTAT" ]; then
        # found qstat 
        true 
    else
        echo "aborting, qstat not found"
        exit
    fi
    
    # continue then and source the startserver.sh to get the config
    if [ ! -r "$1" ]; then
        echo "\"$1\" not readable\""
    else
        # source it
        echo "sourcing \"$1\" for server configuration"
        . "$1" &>/dev/null

        if [ -z "$NET_IP" ]; then
            # assume localhost if emtpy
            NET_IP="localhost"
        fi

        echo "querying $NET_IP:$NET_PORT with $QSTAT"
        RAWQSTAT="$($QSTAT -nh -q3s $NET_IP:$NET_PORT)"
        PLAYERS="$(echo $RAWQSTAT | awk '{ print $2 }' | cut -f1 -d "/")"
        MAP="$(echo $RAWQSTAT |  awk '{ print $3 }')"
        echo "server currently has $PLAYERS players on $MAP"
       
        if [ "$PLAYERS" == "0" -o "$PLAYERS" == "ERROR" -o "$PLAYERS" == "DOWN" ]; then
            echo "attempting restart"
            sh $1 stop
            sh $1 start $MAP
        else
            echo "server not empty, not restarting"
        fi 
    fi
fi

